#[cfg(test)]
mod test {
    use std::error::Error;

    use derive_more::{Deref, DerefMut};
    use mysql_async::Opts;
    use testcontainers_modules::testcontainers::ContainerAsync;

    // This is a bit YOLO but is the quickest/cleanest way I can think of to a) get
    // a connection per database and b) ensure `Drop` cleans it up.
    #[derive(Deref, DerefMut)]
    struct TestPool(
        #[deref]
        #[deref_mut]
        mysql_async::Pool,
        // Never read, only needed for `Drop`.
        #[allow(dead_code)] ContainerAsync<testcontainers_modules::mysql::Mysql>,
    );

    async fn get_test_pool() -> Result<TestPool, Box<dyn Error>> {
        use testcontainers_modules::{mysql, testcontainers::runners::AsyncRunner};
        let mysql = mysql::Mysql::default().start().await?;
        let url = format!(
            "mysql://{}:{}/test",
            mysql.get_host().await?,
            mysql.get_host_port_ipv4(3306).await?
        );
        let opts = Opts::from_url(&url)?;
        let pool = mysql_async::Pool::new(opts);
        Ok(TestPool(pool, mysql))
    }

    #[tokio::test]
    async fn test_mysql() -> Result<(), Box<dyn std::error::Error>> {
        let pool = get_test_pool().await?;
        <mysql_async::Pool as Clone>::clone(&pool)
            .disconnect()
            .await?;
        Ok(())
    }
}
